==> explainability-api-1.6.0.Final-sources.jar: org/kie/kogito/explainability/api/CounterfactualSearchDomainCollectionDto.java <==
/*
 * Copyright 2021 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.kogito.explainability.api;

import java.util.Collection;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;

@JsonIgnoreProperties(ignoreUnknown = true)
public class CounterfactualSearchDomainCollectionDto extends CounterfactualSearchDomainDto {

    public static final String VALUE_FIELD = "value";

    @JsonProperty(VALUE_FIELD)
    private Collection<CounterfactualSearchDomainDto> value;

    public CounterfactualSearchDomainCollectionDto() {
    }

    public CounterfactualSearchDomainCollectionDto(String type) {
        this(type, null);
    }

    public CounterfactualSearchDomainCollectionDto(String type, Collection<CounterfactualSearchDomainDto> value) {
        super(Kind.COLLECTION, type);
        this.value = value;
    }

    public Collection<CounterfactualSearchDomainDto> getValue() {
        return value;
    }
}

==> explainability-api-1.12.0.Final-sources.jar: org/kie/kogito/explainability/api/CounterfactualSearchDomainCollectionDto.java <==
/*
 * Copyright 2021 Red Hat, Inc. and/or its affiliates.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.kie.kogito.explainability.api;

import java.util.Collection;
import java.util.Objects;

import javax.validation.constraints.NotNull;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;

@JsonIgnoreProperties(ignoreUnknown = true)
public class CounterfactualSearchDomainCollectionDto extends CounterfactualSearchDomainDto {

    public static final String VALUE_FIELD = "value";

    @JsonProperty(VALUE_FIELD)
    @NotNull(message = "value object must be provided.")
    private Collection<CounterfactualSearchDomainDto> value;

    public CounterfactualSearchDomainCollectionDto() {
    }

    public CounterfactualSearchDomainCollectionDto(@NotNull String type,
            @NotNull Collection<CounterfactualSearchDomainDto> value) {
        super(Kind.COLLECTION, type);
        this.value = Objects.requireNonNull(value);
    }

    public Collection<CounterfactualSearchDomainDto> getValue() {
        return value;
    }
}
